// lib/dynamic-form-library/dynamic-form-library.mjs
var matDynamicFormLibrary = {
  name: "material",
  references: ["core"]
};

// lib/dynamic-form-dialog/dynamic-form-dialog.component.mjs
import { NgClass, NgIf } from "@angular/common";
import { Component, EventEmitter, Inject, Input, Optional, Output, ViewChild } from "@angular/core";
import { MatDialogConfig, MatDialogModule } from "@angular/material/dialog";
import { DYNAMIC_FORM_THEME, DynamicFormElementsComponent } from "@dynamic-forms/core";
import * as i0 from "@angular/core";
import * as i1 from "@angular/material/dialog";
var MatDynamicFormDialogComponent = class _MatDynamicFormDialogComponent {
  constructor(dialog, theme) {
    this.dialog = dialog;
    this.theme = theme;
    this.escaped = new EventEmitter();
  }
  ngOnChanges(changes) {
    if (this._dialog && changes.maximized) {
      const width = this.getDialogWidth();
      const height = this.getDialogHeight();
      this._dialog.reference.updateSize(width, height);
    }
  }
  ngOnInit() {
    this._dialogOpenSubscription = this.isOpen$.subscribe((isOpen) => isOpen ? this.openDialog() : this.closeDialog());
  }
  ngOnDestroy() {
    this._dialogOpenSubscription.unsubscribe();
    this.closeDialog();
  }
  openDialog() {
    this.closeDialog();
    const config = this.getDialogConfig();
    const reference = this.dialog.open(this.dialogTemplateRef, config);
    const subscription = reference.beforeClosed().subscribe((_) => this.escaped.emit());
    this._dialog = { config, reference, subscription };
  }
  closeDialog() {
    if (this._dialog) {
      this._dialog.reference.close();
      this._dialog.subscription.unsubscribe();
      this._dialog = null;
    }
  }
  getDialogWidth() {
    return this.maximized ? this.maxWidth || "100%" : this.width;
  }
  getDialogHeight() {
    return this.maximized ? this.maxHeight || "100%" : this.height;
  }
  getDialogConfig() {
    const config = new MatDialogConfig();
    config.width = this.getDialogWidth();
    config.height = this.getDialogHeight();
    config.minWidth = this.minWidth;
    config.minHeight = this.minHeight;
    config.maxWidth = this.maxWidth;
    config.maxHeight = this.maxHeight;
    return config;
  }
  static {
    this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i0, type: _MatDynamicFormDialogComponent, deps: [{ token: i1.MatDialog }, { token: DYNAMIC_FORM_THEME, optional: true }], target: i0.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormDialogComponent, isStandalone: true, selector: "mat-dynamic-form-dialog", inputs: { isOpen$: "isOpen$", children: "children", headerActions: "headerActions", footerActions: "footerActions", width: "width", height: "height", minWidth: "minWidth", minHeight: "minHeight", maxWidth: "maxWidth", maxHeight: "maxHeight", maximized: "maximized", title: "title", titleHtml: "titleHtml", classNameForm: "classNameForm", classNameModal: "classNameModal", classNameChildren: "classNameChildren", classNameHeader: "classNameHeader", classNameFooter: "classNameFooter", classNameTitle: "classNameTitle" }, outputs: { escaped: "escaped" }, viewQueries: [{ propertyName: "dialogTemplateRef", first: true, predicate: ["dialogTemplateRef"], descendants: true, static: true }], usesOnChanges: true, ngImport: i0, template: '<ng-template #dialogTemplateRef>\n  <div class="dynamic-form-wrapper" [ngClass]="theme" [class.maximized]="maximized">\n    <div class="dynamic-form" [ngClass]="classNameForm" [class.maximized]="maximized">\n      <div class="dynamic-form-modal" [ngClass]="classNameModal" [class.maximized]="maximized">\n        <div *ngIf="title || titleHtml || headerActions?.length" class="modal-header" [ngClass]="classNameHeader">\n          <div *ngIf="titleHtml; else titlePlain" class="modal-title" [ngClass]="classNameTitle" [innerHTML]="titleHtml"></div>\n          <ng-template #titlePlain>\n            <div class="modal-title" [ngClass]="classNameTitle">{{ title }}</div>\n          </ng-template>\n          <div *ngIf="headerActions?.length" class="modal-toolbar">\n            <dynamic-form-elements [elements]="headerActions" />\n          </div>\n        </div>\n        <mat-dialog-content class="modal-body" [ngClass]="classNameChildren" [class.maximized]="maximized">\n          <dynamic-form-elements [elements]="children" />\n        </mat-dialog-content>\n        <mat-dialog-actions *ngIf="footerActions?.length" class="modal-footer" [ngClass]="classNameFooter">\n          <dynamic-form-elements [elements]="footerActions" />\n        </mat-dialog-actions>\n      </div>\n    </div>\n  </div>\n</ng-template>\n', dependencies: [{ kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: DynamicFormElementsComponent, selector: "dynamic-form-elements", inputs: ["elements"] }] });
  }
};
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i0, type: MatDynamicFormDialogComponent, decorators: [{
  type: Component,
  args: [{ standalone: true, selector: "mat-dynamic-form-dialog", imports: [NgClass, NgIf, MatDialogModule, DynamicFormElementsComponent], template: '<ng-template #dialogTemplateRef>\n  <div class="dynamic-form-wrapper" [ngClass]="theme" [class.maximized]="maximized">\n    <div class="dynamic-form" [ngClass]="classNameForm" [class.maximized]="maximized">\n      <div class="dynamic-form-modal" [ngClass]="classNameModal" [class.maximized]="maximized">\n        <div *ngIf="title || titleHtml || headerActions?.length" class="modal-header" [ngClass]="classNameHeader">\n          <div *ngIf="titleHtml; else titlePlain" class="modal-title" [ngClass]="classNameTitle" [innerHTML]="titleHtml"></div>\n          <ng-template #titlePlain>\n            <div class="modal-title" [ngClass]="classNameTitle">{{ title }}</div>\n          </ng-template>\n          <div *ngIf="headerActions?.length" class="modal-toolbar">\n            <dynamic-form-elements [elements]="headerActions" />\n          </div>\n        </div>\n        <mat-dialog-content class="modal-body" [ngClass]="classNameChildren" [class.maximized]="maximized">\n          <dynamic-form-elements [elements]="children" />\n        </mat-dialog-content>\n        <mat-dialog-actions *ngIf="footerActions?.length" class="modal-footer" [ngClass]="classNameFooter">\n          <dynamic-form-elements [elements]="footerActions" />\n        </mat-dialog-actions>\n      </div>\n    </div>\n  </div>\n</ng-template>\n' }]
}], ctorParameters: () => [{ type: i1.MatDialog }, { type: void 0, decorators: [{
  type: Optional
}, {
  type: Inject,
  args: [DYNAMIC_FORM_THEME]
}] }], propDecorators: { dialogTemplateRef: [{
  type: ViewChild,
  args: ["dialogTemplateRef", { static: true }]
}], isOpen$: [{
  type: Input
}], children: [{
  type: Input
}], headerActions: [{
  type: Input
}], footerActions: [{
  type: Input
}], width: [{
  type: Input
}], height: [{
  type: Input
}], minWidth: [{
  type: Input
}], minHeight: [{
  type: Input
}], maxWidth: [{
  type: Input
}], maxHeight: [{
  type: Input
}], maximized: [{
  type: Input
}], title: [{
  type: Input
}], titleHtml: [{
  type: Input
}], classNameForm: [{
  type: Input
}], classNameModal: [{
  type: Input
}], classNameChildren: [{
  type: Input
}], classNameHeader: [{
  type: Input
}], classNameFooter: [{
  type: Input
}], classNameTitle: [{
  type: Input
}], escaped: [{
  type: Output
}] } });

// lib/dynamic-form-action/dynamic-form-button/dynamic-form-button.component.mjs
import { NgClass as NgClass2, NgIf as NgIf2 } from "@angular/common";
import { Component as Component2 } from "@angular/core";
import { MatButtonModule } from "@angular/material/button";
import { DynamicFormButtonBase, DynamicFormColorPipe } from "@dynamic-forms/core";
import * as i02 from "@angular/core";
import * as i12 from "@dynamic-forms/core";
import * as i2 from "@angular/material/button";
var MatDynamicFormButtonComponent = class _MatDynamicFormButtonComponent extends DynamicFormButtonBase {
  constructor(actionService) {
    super(actionService);
    this.actionService = actionService;
  }
  static {
    this.ɵfac = i02.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i02, type: _MatDynamicFormButtonComponent, deps: [{ token: i12.DynamicFormActionService }], target: i02.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i02.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormButtonComponent, isStandalone: true, selector: "mat-dynamic-form-button", usesInheritance: true, ngImport: i02, template: `<a
  *ngIf="template.url; else button"
  mat-flat-button
  class="dynamic-form-button"
  [ngClass]="template.className"
  [color]="template.color | dynamicFormColor: 'primary'"
  [disabled]="template.disabled"
  [hidden]="template.hidden"
  [href]="template.url"
  [target]="template.urlTarget || '_blank'"
  >{{ template.label }}</a
>

<ng-template #button>
  <button
    mat-flat-button
    class="dynamic-form-button"
    [id]="id"
    [ngClass]="template.className"
    [color]="template.color | dynamicFormColor: 'primary'"
    [type]="template.type || 'button'"
    [disabled]="template.disabled"
    [hidden]="template.hidden"
    (click)="onClick($event)"
    >{{ template.label }}</button
  >
</ng-template>

<mat-dynamic-form-dialog
  *ngIf="dialog"
  [isOpen$]="dialogOpen$"
  [children]="dialogChildren"
  [headerActions]="dialogHeaderActions"
  [footerActions]="dialogFooterActions"
  [width]="template.dialogWidth"
  [minWidth]="template.dialogMinWidth"
  [maxWidth]="template.dialogMaxWidth"
  [title]="template.dialogTitle"
  [titleHtml]="template.dialogTitleHtml"
  [classNameForm]="element.root.template.className"
  [classNameModal]="template.className"
  [classNameTitle]="template.classNameDialogTitle"
  [classNameChildren]="dialogTemplate?.classNameChildren"
  [classNameHeader]="dialogTemplate?.classNameHeader"
  [classNameFooter]="dialogTemplate?.classNameFooter"
  (escaped)="closeDialog()"
/>
`, dependencies: [{ kind: "directive", type: NgClass2, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgIf2, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: DynamicFormColorPipe, name: "dynamicFormColor" }, { kind: "component", type: MatDynamicFormDialogComponent, selector: "mat-dynamic-form-dialog", inputs: ["isOpen$", "children", "headerActions", "footerActions", "width", "height", "minWidth", "minHeight", "maxWidth", "maxHeight", "maximized", "title", "titleHtml", "classNameForm", "classNameModal", "classNameChildren", "classNameHeader", "classNameFooter", "classNameTitle"], outputs: ["escaped"] }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatAnchor, selector: "a[mat-button], a[mat-raised-button], a[mat-flat-button], a[mat-stroked-button]", exportAs: ["matButton", "matAnchor"] }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }] });
  }
};
i02.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i02, type: MatDynamicFormButtonComponent, decorators: [{
  type: Component2,
  args: [{ standalone: true, selector: "mat-dynamic-form-button", imports: [NgClass2, NgIf2, DynamicFormColorPipe, MatDynamicFormDialogComponent, MatButtonModule], template: `<a
  *ngIf="template.url; else button"
  mat-flat-button
  class="dynamic-form-button"
  [ngClass]="template.className"
  [color]="template.color | dynamicFormColor: 'primary'"
  [disabled]="template.disabled"
  [hidden]="template.hidden"
  [href]="template.url"
  [target]="template.urlTarget || '_blank'"
  >{{ template.label }}</a
>

<ng-template #button>
  <button
    mat-flat-button
    class="dynamic-form-button"
    [id]="id"
    [ngClass]="template.className"
    [color]="template.color | dynamicFormColor: 'primary'"
    [type]="template.type || 'button'"
    [disabled]="template.disabled"
    [hidden]="template.hidden"
    (click)="onClick($event)"
    >{{ template.label }}</button
  >
</ng-template>

<mat-dynamic-form-dialog
  *ngIf="dialog"
  [isOpen$]="dialogOpen$"
  [children]="dialogChildren"
  [headerActions]="dialogHeaderActions"
  [footerActions]="dialogFooterActions"
  [width]="template.dialogWidth"
  [minWidth]="template.dialogMinWidth"
  [maxWidth]="template.dialogMaxWidth"
  [title]="template.dialogTitle"
  [titleHtml]="template.dialogTitleHtml"
  [classNameForm]="element.root.template.className"
  [classNameModal]="template.className"
  [classNameTitle]="template.classNameDialogTitle"
  [classNameChildren]="dialogTemplate?.classNameChildren"
  [classNameHeader]="dialogTemplate?.classNameHeader"
  [classNameFooter]="dialogTemplate?.classNameFooter"
  (escaped)="closeDialog()"
/>
` }]
}], ctorParameters: () => [{ type: i12.DynamicFormActionService }] });

// lib/dynamic-form-action/dynamic-form-button/dynamic-form-button-type.mjs
var matDynamicFormButtonType = {
  type: "button",
  component: MatDynamicFormButtonComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-action/dynamic-form-icon/dynamic-form-icon.component.mjs
import { NgClass as NgClass3, NgIf as NgIf3 } from "@angular/common";
import { Component as Component3 } from "@angular/core";
import { MatButtonModule as MatButtonModule2 } from "@angular/material/button";
import { MatIconModule } from "@angular/material/icon";
import { MatTooltipModule } from "@angular/material/tooltip";
import { DynamicFormColorPipe as DynamicFormColorPipe2, DynamicFormIconBase, DynamicFormIconPipe } from "@dynamic-forms/core";
import * as i03 from "@angular/core";
import * as i13 from "@dynamic-forms/core";
import * as i22 from "@angular/material/button";
import * as i3 from "@angular/material/icon";
import * as i4 from "@angular/material/tooltip";
var MatDynamicFormIconComponent = class _MatDynamicFormIconComponent extends DynamicFormIconBase {
  constructor(actionService) {
    super(actionService);
    this.actionService = actionService;
  }
  static {
    this.ɵfac = i03.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i03, type: _MatDynamicFormIconComponent, deps: [{ token: i13.DynamicFormActionService }], target: i03.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i03.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormIconComponent, isStandalone: true, selector: "mat-dynamic-form-icon", usesInheritance: true, ngImport: i03, template: `<div class="dynamic-form-icon-wrapper" [ngClass]="template.classNameWrapper">
  <a
    *ngIf="template.url; else button"
    mat-icon-button
    class="dynamic-form-icon"
    [ngClass]="template.className"
    [color]="template.color | dynamicFormColor: 'primary'"
    [disabled]="template.disabled"
    [hidden]="template.hidden"
    [matTooltip]="template.label"
    [href]="template.url"
    [target]="template.urlTarget || '_blank'"
  >
    <mat-icon>{{ template.icon | dynamicFormIcon }}</mat-icon></a
  >

  <ng-template #button>
    <button
      mat-icon-button
      class="dynamic-form-icon"
      [id]="id"
      [ngClass]="template.className"
      [color]="template.color | dynamicFormColor: 'primary'"
      [type]="template.type || 'button'"
      [disabled]="template.disabled"
      [hidden]="template.hidden"
      [matTooltip]="template.label"
      (click)="onClick($event)"
    >
      <mat-icon>{{ template.icon | dynamicFormIcon }}</mat-icon>
    </button>
  </ng-template>
</div>

<mat-dynamic-form-dialog
  *ngIf="dialog"
  [isOpen$]="dialogOpen$"
  [children]="dialogChildren"
  [headerActions]="dialogHeaderActions"
  [footerActions]="dialogFooterActions"
  [width]="template.dialogWidth"
  [minWidth]="template.dialogMinWidth"
  [maxWidth]="template.dialogMaxWidth"
  [title]="template.dialogTitle"
  [titleHtml]="template.dialogTitleHtml"
  [classNameForm]="element.root.template.className"
  [classNameModal]="template.className"
  [classNameTitle]="template.classNameDialogTitle"
  [classNameChildren]="dialogTemplate?.classNameChildren"
  [classNameHeader]="dialogTemplate?.classNameHeader"
  [classNameFooter]="dialogTemplate?.classNameFooter"
  (escaped)="closeDialog()"
/>
`, dependencies: [{ kind: "directive", type: NgClass3, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgIf3, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: DynamicFormColorPipe2, name: "dynamicFormColor" }, { kind: "pipe", type: DynamicFormIconPipe, name: "dynamicFormIcon" }, { kind: "component", type: MatDynamicFormDialogComponent, selector: "mat-dynamic-form-dialog", inputs: ["isOpen$", "children", "headerActions", "footerActions", "width", "height", "minWidth", "minHeight", "maxWidth", "maxHeight", "maximized", "title", "titleHtml", "classNameForm", "classNameModal", "classNameChildren", "classNameHeader", "classNameFooter", "classNameTitle"], outputs: ["escaped"] }, { kind: "ngmodule", type: MatButtonModule2 }, { kind: "component", type: i22.MatIconAnchor, selector: "a[mat-icon-button]", exportAs: ["matButton", "matAnchor"] }, { kind: "component", type: i22.MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }, { kind: "ngmodule", type: MatIconModule }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "ngmodule", type: MatTooltipModule }, { kind: "directive", type: i4.MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }] });
  }
};
i03.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i03, type: MatDynamicFormIconComponent, decorators: [{
  type: Component3,
  args: [{ standalone: true, selector: "mat-dynamic-form-icon", imports: [
    NgClass3,
    NgIf3,
    DynamicFormColorPipe2,
    DynamicFormIconPipe,
    MatDynamicFormDialogComponent,
    MatButtonModule2,
    MatIconModule,
    MatTooltipModule
  ], template: `<div class="dynamic-form-icon-wrapper" [ngClass]="template.classNameWrapper">
  <a
    *ngIf="template.url; else button"
    mat-icon-button
    class="dynamic-form-icon"
    [ngClass]="template.className"
    [color]="template.color | dynamicFormColor: 'primary'"
    [disabled]="template.disabled"
    [hidden]="template.hidden"
    [matTooltip]="template.label"
    [href]="template.url"
    [target]="template.urlTarget || '_blank'"
  >
    <mat-icon>{{ template.icon | dynamicFormIcon }}</mat-icon></a
  >

  <ng-template #button>
    <button
      mat-icon-button
      class="dynamic-form-icon"
      [id]="id"
      [ngClass]="template.className"
      [color]="template.color | dynamicFormColor: 'primary'"
      [type]="template.type || 'button'"
      [disabled]="template.disabled"
      [hidden]="template.hidden"
      [matTooltip]="template.label"
      (click)="onClick($event)"
    >
      <mat-icon>{{ template.icon | dynamicFormIcon }}</mat-icon>
    </button>
  </ng-template>
</div>

<mat-dynamic-form-dialog
  *ngIf="dialog"
  [isOpen$]="dialogOpen$"
  [children]="dialogChildren"
  [headerActions]="dialogHeaderActions"
  [footerActions]="dialogFooterActions"
  [width]="template.dialogWidth"
  [minWidth]="template.dialogMinWidth"
  [maxWidth]="template.dialogMaxWidth"
  [title]="template.dialogTitle"
  [titleHtml]="template.dialogTitleHtml"
  [classNameForm]="element.root.template.className"
  [classNameModal]="template.className"
  [classNameTitle]="template.classNameDialogTitle"
  [classNameChildren]="dialogTemplate?.classNameChildren"
  [classNameHeader]="dialogTemplate?.classNameHeader"
  [classNameFooter]="dialogTemplate?.classNameFooter"
  (escaped)="closeDialog()"
/>
` }]
}], ctorParameters: () => [{ type: i13.DynamicFormActionService }] });

// lib/dynamic-form-action/dynamic-form-icon/dynamic-form-icon-type.mjs
var matDynamicFormIconType = {
  type: "icon",
  component: MatDynamicFormIconComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-action/dynamic-form-action.module.mjs
import { NgModule } from "@angular/core";
import { DynamicFormActionModule, DynamicFormConfigModule, importDynamicFormsProviders, withDynamicFormActions } from "@dynamic-forms/core";
import * as i04 from "@angular/core";
var matDynamicFormActionTypes = [matDynamicFormButtonType, matDynamicFormIconType];
function withMatDynamicFormActionDefaultFeatures() {
  return [withDynamicFormActions(...matDynamicFormActionTypes)];
}
var modules = [DynamicFormActionModule, DynamicFormConfigModule];
var MatDynamicFormActionModule = class _MatDynamicFormActionModule {
  static {
    this.ɵfac = i04.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i04, type: _MatDynamicFormActionModule, deps: [], target: i04.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i04.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i04, type: _MatDynamicFormActionModule, imports: [DynamicFormActionModule, DynamicFormConfigModule], exports: [DynamicFormActionModule, DynamicFormConfigModule] });
  }
  static {
    this.ɵinj = i04.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i04, type: _MatDynamicFormActionModule, providers: importDynamicFormsProviders(...withMatDynamicFormActionDefaultFeatures()), imports: [modules, DynamicFormActionModule, DynamicFormConfigModule] });
  }
};
i04.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i04, type: MatDynamicFormActionModule, decorators: [{
  type: NgModule,
  args: [{
    imports: modules,
    exports: modules,
    providers: importDynamicFormsProviders(...withMatDynamicFormActionDefaultFeatures())
  }]
}] });

// lib/dynamic-form-element/dynamic-form-items/dynamic-form-accordion/dynamic-form-accordion.component.mjs
import { NgClass as NgClass4, NgFor } from "@angular/common";
import { Component as Component4 } from "@angular/core";
import { MatExpansionModule } from "@angular/material/expansion";
import { DynamicFormAccordionBase, DynamicFormElementsComponent as DynamicFormElementsComponent2 } from "@dynamic-forms/core";
import * as i05 from "@angular/core";
import * as i14 from "@angular/material/expansion";
var MatDynamicFormAccordionComponent = class _MatDynamicFormAccordionComponent extends DynamicFormAccordionBase {
  constructor() {
    super();
  }
  static {
    this.ɵfac = i05.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i05, type: _MatDynamicFormAccordionComponent, deps: [], target: i05.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i05.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormAccordionComponent, isStandalone: true, selector: "mat-dynamic-form-accordion", usesInheritance: true, ngImport: i05, template: '<mat-accordion class="dynamic-form-items dynamic-form-accordion" [ngClass]="template.className" [hidden]="template.hidden">\n  <mat-expansion-panel\n    *ngFor="let child of element.children; let index = index"\n    [ngClass]="child.template.className"\n    [expanded]="index === selectedIndex"\n    [disabled]="child.disabled"\n    [hidden]="child.template.hidden"\n    (opened)="openItem(index)"\n    (closed)="closeItem(index)"\n  >\n    <mat-expansion-panel-header class="dynamic-form-item-header">\n      <mat-panel-title>{{ child.label }}</mat-panel-title>\n    </mat-expansion-panel-header>\n    <ng-template matExpansionPanelContent>\n      <div class="dynamic-form-item">\n        <dynamic-form-elements [elements]="child.children" />\n      </div>\n    </ng-template>\n  </mat-expansion-panel>\n</mat-accordion>\n', dependencies: [{ kind: "directive", type: NgClass4, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "ngmodule", type: MatExpansionModule }, { kind: "directive", type: i14.MatAccordion, selector: "mat-accordion", inputs: ["hideToggle", "displayMode", "togglePosition"], exportAs: ["matAccordion"] }, { kind: "component", type: i14.MatExpansionPanel, selector: "mat-expansion-panel", inputs: ["hideToggle", "togglePosition"], outputs: ["afterExpand", "afterCollapse"], exportAs: ["matExpansionPanel"] }, { kind: "component", type: i14.MatExpansionPanelHeader, selector: "mat-expansion-panel-header", inputs: ["expandedHeight", "collapsedHeight", "tabIndex"] }, { kind: "directive", type: i14.MatExpansionPanelTitle, selector: "mat-panel-title" }, { kind: "directive", type: i14.MatExpansionPanelContent, selector: "ng-template[matExpansionPanelContent]" }, { kind: "component", type: DynamicFormElementsComponent2, selector: "dynamic-form-elements", inputs: ["elements"] }] });
  }
};
i05.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i05, type: MatDynamicFormAccordionComponent, decorators: [{
  type: Component4,
  args: [{ standalone: true, selector: "mat-dynamic-form-accordion", imports: [NgClass4, NgFor, MatExpansionModule, DynamicFormElementsComponent2], template: '<mat-accordion class="dynamic-form-items dynamic-form-accordion" [ngClass]="template.className" [hidden]="template.hidden">\n  <mat-expansion-panel\n    *ngFor="let child of element.children; let index = index"\n    [ngClass]="child.template.className"\n    [expanded]="index === selectedIndex"\n    [disabled]="child.disabled"\n    [hidden]="child.template.hidden"\n    (opened)="openItem(index)"\n    (closed)="closeItem(index)"\n  >\n    <mat-expansion-panel-header class="dynamic-form-item-header">\n      <mat-panel-title>{{ child.label }}</mat-panel-title>\n    </mat-expansion-panel-header>\n    <ng-template matExpansionPanelContent>\n      <div class="dynamic-form-item">\n        <dynamic-form-elements [elements]="child.children" />\n      </div>\n    </ng-template>\n  </mat-expansion-panel>\n</mat-accordion>\n' }]
}], ctorParameters: () => [] });

// lib/dynamic-form-element/dynamic-form-items/dynamic-form-accordion/dynamic-form-accordion.module.mjs
import { NgModule as NgModule2 } from "@angular/core";
import { DynamicFormConfigModule as DynamicFormConfigModule2, dynamicFormItemsFactory, importDynamicFormsProviders as importDynamicFormsProviders2, withDynamicFormElements } from "@dynamic-forms/core";
import * as i06 from "@angular/core";
var matDynamicFormAccordionType = {
  type: "accordion",
  factory: dynamicFormItemsFactory,
  component: MatDynamicFormAccordionComponent,
  libraryName: matDynamicFormLibrary.name
};
var modules2 = [DynamicFormConfigModule2];
var MatDynamicFormAccordionModule = class _MatDynamicFormAccordionModule {
  static {
    this.ɵfac = i06.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i06, type: _MatDynamicFormAccordionModule, deps: [], target: i06.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i06.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i06, type: _MatDynamicFormAccordionModule, imports: [DynamicFormConfigModule2], exports: [DynamicFormConfigModule2] });
  }
  static {
    this.ɵinj = i06.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i06, type: _MatDynamicFormAccordionModule, providers: importDynamicFormsProviders2(withDynamicFormElements(matDynamicFormAccordionType)), imports: [modules2, DynamicFormConfigModule2] });
  }
};
i06.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i06, type: MatDynamicFormAccordionModule, decorators: [{
  type: NgModule2,
  args: [{
    imports: modules2,
    exports: modules2,
    providers: importDynamicFormsProviders2(withDynamicFormElements(matDynamicFormAccordionType))
  }]
}] });

// lib/dynamic-form-element/dynamic-form-items/dynamic-form-tabs/dynamic-form-tabs.component.mjs
import { NgClass as NgClass5, NgFor as NgFor2 } from "@angular/common";
import { Component as Component5 } from "@angular/core";
import { MatTabsModule } from "@angular/material/tabs";
import { DynamicFormElementsComponent as DynamicFormElementsComponent3, DynamicFormTabsBase } from "@dynamic-forms/core";
import * as i07 from "@angular/core";
import * as i15 from "@angular/material/tabs";
var MatDynamicFormTabsComponent = class _MatDynamicFormTabsComponent extends DynamicFormTabsBase {
  constructor() {
    super();
  }
  static {
    this.ɵfac = i07.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i07, type: _MatDynamicFormTabsComponent, deps: [], target: i07.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i07.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormTabsComponent, isStandalone: true, selector: "mat-dynamic-form-tabs", usesInheritance: true, ngImport: i07, template: '<mat-tab-group\n  class="dynamic-form-items dynamic-form-tabs"\n  [ngClass]="template.className"\n  [hidden]="template.hidden"\n  [selectedIndex]="selectedIndex"\n  (selectedIndexChange)="selectItem($event)"\n>\n  <mat-tab\n    *ngFor="let child of element.children"\n    [ngClass]="child.template.className"\n    [disabled]="child.disabled"\n    [hidden]="template.hidden"\n  >\n    <ng-template matTabLabel>\n      <div class="dynamic-form-item-header">{{ child.label }}</div>\n    </ng-template>\n    <ng-template matTabContent>\n      <div class="dynamic-form-item">\n        <dynamic-form-elements [elements]="child.children" />\n      </div>\n    </ng-template>\n  </mat-tab>\n</mat-tab-group>\n', dependencies: [{ kind: "directive", type: NgClass5, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgFor2, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "ngmodule", type: MatTabsModule }, { kind: "directive", type: i15.MatTabContent, selector: "[matTabContent]" }, { kind: "directive", type: i15.MatTabLabel, selector: "[mat-tab-label], [matTabLabel]" }, { kind: "component", type: i15.MatTab, selector: "mat-tab", inputs: ["disabled", "label", "aria-label", "aria-labelledby", "labelClass", "bodyClass"], exportAs: ["matTab"] }, { kind: "component", type: i15.MatTabGroup, selector: "mat-tab-group", inputs: ["color", "fitInkBarToContent", "mat-stretch-tabs", "dynamicHeight", "selectedIndex", "headerPosition", "animationDuration", "contentTabIndex", "disablePagination", "disableRipple", "preserveContent", "backgroundColor"], outputs: ["selectedIndexChange", "focusChange", "animationDone", "selectedTabChange"], exportAs: ["matTabGroup"] }, { kind: "component", type: DynamicFormElementsComponent3, selector: "dynamic-form-elements", inputs: ["elements"] }] });
  }
};
i07.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i07, type: MatDynamicFormTabsComponent, decorators: [{
  type: Component5,
  args: [{ standalone: true, selector: "mat-dynamic-form-tabs", imports: [NgClass5, NgFor2, MatTabsModule, DynamicFormElementsComponent3], template: '<mat-tab-group\n  class="dynamic-form-items dynamic-form-tabs"\n  [ngClass]="template.className"\n  [hidden]="template.hidden"\n  [selectedIndex]="selectedIndex"\n  (selectedIndexChange)="selectItem($event)"\n>\n  <mat-tab\n    *ngFor="let child of element.children"\n    [ngClass]="child.template.className"\n    [disabled]="child.disabled"\n    [hidden]="template.hidden"\n  >\n    <ng-template matTabLabel>\n      <div class="dynamic-form-item-header">{{ child.label }}</div>\n    </ng-template>\n    <ng-template matTabContent>\n      <div class="dynamic-form-item">\n        <dynamic-form-elements [elements]="child.children" />\n      </div>\n    </ng-template>\n  </mat-tab>\n</mat-tab-group>\n' }]
}], ctorParameters: () => [] });

// lib/dynamic-form-element/dynamic-form-items/dynamic-form-tabs/dynamic-form-tabs.module.mjs
import { NgModule as NgModule3 } from "@angular/core";
import { DynamicFormConfigModule as DynamicFormConfigModule3, dynamicFormItemsFactory as dynamicFormItemsFactory2, importDynamicFormsProviders as importDynamicFormsProviders3, withDynamicFormElements as withDynamicFormElements2 } from "@dynamic-forms/core";
import * as i08 from "@angular/core";
var matDynamicFormTabsType = {
  type: "tabs",
  factory: dynamicFormItemsFactory2,
  component: MatDynamicFormTabsComponent,
  libraryName: matDynamicFormLibrary.name
};
var modules3 = [DynamicFormConfigModule3];
var MatDynamicFormTabsModule = class _MatDynamicFormTabsModule {
  static {
    this.ɵfac = i08.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i08, type: _MatDynamicFormTabsModule, deps: [], target: i08.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i08.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i08, type: _MatDynamicFormTabsModule, imports: [DynamicFormConfigModule3], exports: [DynamicFormConfigModule3] });
  }
  static {
    this.ɵinj = i08.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i08, type: _MatDynamicFormTabsModule, providers: importDynamicFormsProviders3(withDynamicFormElements2(matDynamicFormTabsType)), imports: [modules3, DynamicFormConfigModule3] });
  }
};
i08.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i08, type: MatDynamicFormTabsModule, decorators: [{
  type: NgModule3,
  args: [{
    imports: modules3,
    exports: modules3,
    providers: importDynamicFormsProviders3(withDynamicFormElements2(matDynamicFormTabsType))
  }]
}] });

// lib/dynamic-form-element/dynamic-form-items/dynamic-form-items.module.mjs
import { NgModule as NgModule4 } from "@angular/core";
import * as i09 from "@angular/core";
var modules4 = [MatDynamicFormAccordionModule, MatDynamicFormTabsModule];
var MatDynamicFormItemsModule = class _MatDynamicFormItemsModule {
  static {
    this.ɵfac = i09.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i09, type: _MatDynamicFormItemsModule, deps: [], target: i09.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i09.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i09, type: _MatDynamicFormItemsModule, imports: [MatDynamicFormAccordionModule, MatDynamicFormTabsModule], exports: [MatDynamicFormAccordionModule, MatDynamicFormTabsModule] });
  }
  static {
    this.ɵinj = i09.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i09, type: _MatDynamicFormItemsModule, imports: [modules4, MatDynamicFormAccordionModule, MatDynamicFormTabsModule] });
  }
};
i09.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i09, type: MatDynamicFormItemsModule, decorators: [{
  type: NgModule4,
  args: [{
    imports: modules4,
    exports: modules4
  }]
}] });

// lib/dynamic-form-element/dynamic-form-modal/dynamic-form-modal.component.mjs
import { NgIf as NgIf4 } from "@angular/common";
import { Component as Component6 } from "@angular/core";
import { DynamicFormElementComponent, DynamicFormModalBase } from "@dynamic-forms/core";
import * as i010 from "@angular/core";
var MatDynamicFormModalComponent = class _MatDynamicFormModalComponent extends DynamicFormModalBase {
  static {
    this.ɵfac = i010.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i010, type: _MatDynamicFormModalComponent, deps: null, target: i010.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i010.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormModalComponent, isStandalone: true, selector: "mat-dynamic-form-modal", usesInheritance: true, ngImport: i010, template: '<dynamic-form-element *ngIf="trigger" [element]="trigger" />\n\n<mat-dynamic-form-dialog\n  [isOpen$]="isOpen$"\n  [children]="children"\n  [headerActions]="headerActions"\n  [footerActions]="footerActions"\n  [width]="template.width"\n  [height]="template.height"\n  [minWidth]="template.minWidth"\n  [minHeight]="template.minHeight"\n  [maxWidth]="template.maxWidth"\n  [maxHeight]="template.maxHeight"\n  [maximized]="template.maximized"\n  [title]="template.title"\n  [titleHtml]="template.titleHtml"\n  [classNameForm]="element.root.template.className"\n  [classNameModal]="template.className"\n  [classNameTitle]="template.classNameTitle"\n  [classNameChildren]="template.classNameChildren"\n  [classNameHeader]="template.classNameHeader"\n  [classNameFooter]="template.classNameFooter"\n  (escaped)="element.close()"\n/>\n', dependencies: [{ kind: "directive", type: NgIf4, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: DynamicFormElementComponent, selector: "dynamic-form-element" }, { kind: "component", type: MatDynamicFormDialogComponent, selector: "mat-dynamic-form-dialog", inputs: ["isOpen$", "children", "headerActions", "footerActions", "width", "height", "minWidth", "minHeight", "maxWidth", "maxHeight", "maximized", "title", "titleHtml", "classNameForm", "classNameModal", "classNameChildren", "classNameHeader", "classNameFooter", "classNameTitle"], outputs: ["escaped"] }] });
  }
};
i010.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i010, type: MatDynamicFormModalComponent, decorators: [{
  type: Component6,
  args: [{ standalone: true, selector: "mat-dynamic-form-modal", imports: [NgIf4, DynamicFormElementComponent, MatDynamicFormDialogComponent], template: '<dynamic-form-element *ngIf="trigger" [element]="trigger" />\n\n<mat-dynamic-form-dialog\n  [isOpen$]="isOpen$"\n  [children]="children"\n  [headerActions]="headerActions"\n  [footerActions]="footerActions"\n  [width]="template.width"\n  [height]="template.height"\n  [minWidth]="template.minWidth"\n  [minHeight]="template.minHeight"\n  [maxWidth]="template.maxWidth"\n  [maxHeight]="template.maxHeight"\n  [maximized]="template.maximized"\n  [title]="template.title"\n  [titleHtml]="template.titleHtml"\n  [classNameForm]="element.root.template.className"\n  [classNameModal]="template.className"\n  [classNameTitle]="template.classNameTitle"\n  [classNameChildren]="template.classNameChildren"\n  [classNameHeader]="template.classNameHeader"\n  [classNameFooter]="template.classNameFooter"\n  (escaped)="element.close()"\n/>\n' }]
}] });

// lib/dynamic-form-element/dynamic-form-modal/dynamic-form-modal.module.mjs
import { NgModule as NgModule5 } from "@angular/core";
import { DynamicFormModalModule, dynamicFormModalFactory, importDynamicFormsProviders as importDynamicFormsProviders4, withDynamicFormElements as withDynamicFormElements3 } from "@dynamic-forms/core";
import * as i011 from "@angular/core";
var matDynamicFormModalType = {
  type: "modal",
  factory: dynamicFormModalFactory,
  component: MatDynamicFormModalComponent,
  libraryName: matDynamicFormLibrary.name
};
var modules5 = [DynamicFormModalModule];
var MatDynamicFormModalModule = class _MatDynamicFormModalModule {
  static {
    this.ɵfac = i011.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i011, type: _MatDynamicFormModalModule, deps: [], target: i011.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i011.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i011, type: _MatDynamicFormModalModule, imports: [DynamicFormModalModule], exports: [DynamicFormModalModule] });
  }
  static {
    this.ɵinj = i011.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i011, type: _MatDynamicFormModalModule, providers: importDynamicFormsProviders4(withDynamicFormElements3(matDynamicFormModalType)), imports: [modules5, DynamicFormModalModule] });
  }
};
i011.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i011, type: MatDynamicFormModalModule, decorators: [{
  type: NgModule5,
  args: [{
    imports: modules5,
    exports: modules5,
    providers: importDynamicFormsProviders4(withDynamicFormElements3(matDynamicFormModalType))
  }]
}] });

// lib/dynamic-form-element/dynamic-form-element.module.mjs
import { NgModule as NgModule6 } from "@angular/core";
import { withDynamicFormElements as withDynamicFormElements4, withDynamicFormModalActionHandlers } from "@dynamic-forms/core";
import * as i012 from "@angular/core";
var matDynamicFormElementTypes = [matDynamicFormAccordionType, matDynamicFormTabsType, matDynamicFormModalType];
function withMatDynamicFormElementDefaultFeatures() {
  return [withDynamicFormElements4(...matDynamicFormElementTypes), withDynamicFormModalActionHandlers()];
}
var modules6 = [MatDynamicFormItemsModule, MatDynamicFormModalModule];
var MatDynamicFormElementModule = class _MatDynamicFormElementModule {
  static {
    this.ɵfac = i012.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i012, type: _MatDynamicFormElementModule, deps: [], target: i012.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i012.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i012, type: _MatDynamicFormElementModule, imports: [MatDynamicFormItemsModule, MatDynamicFormModalModule], exports: [MatDynamicFormItemsModule, MatDynamicFormModalModule] });
  }
  static {
    this.ɵinj = i012.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i012, type: _MatDynamicFormElementModule, imports: [modules6, MatDynamicFormItemsModule, MatDynamicFormModalModule] });
  }
};
i012.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i012, type: MatDynamicFormElementModule, decorators: [{
  type: NgModule6,
  args: [{
    imports: modules6,
    exports: modules6
  }]
}] });

// lib/dynamic-form-input/dynamic-form-input-wrapper/dynamic-form-input-wrapper.component.mjs
import { NgClass as NgClass6, NgIf as NgIf5 } from "@angular/common";
import { Component as Component7, Input as Input2 } from "@angular/core";
import * as i013 from "@angular/core";
var MatDynamicFormInputWrapperComponent = class _MatDynamicFormInputWrapperComponent {
  static {
    this.ɵfac = i013.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i013, type: _MatDynamicFormInputWrapperComponent, deps: [], target: i013.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i013.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormInputWrapperComponent, isStandalone: true, selector: "mat-dynamic-form-input-wrapper", inputs: { label: "label", inputId: "inputId", required: "required", disabled: "disabled", invalid: "invalid", errorMessage: "errorMessage" }, ngImport: i013, template: `<div
  class="mat-mdc-form-field mat-mdc-form-field-wrapper"
  [ngClass]="{ 'mdc-text-field--disabled': disabled, 'mdc-text-field--invalid': invalid }"
>
  <div class="mat-mdc-form-field-input-wrapper">
    <label *ngIf="label" class="mat-mdc-form-field-input-label mat-mdc-floating-label mdc-floating-label" [for]="inputId"
      >{{ label }}<span *ngIf="required">*</span></label
    >
    <ng-content />
  </div>
  <div class="mat-mdc-form-field-subscript-wrapper mat-mdc-form-field-bottom-align">
    <div *ngIf="invalid" class="mat-mdc-form-field-error-wrapper">
      <div class="mat-mdc-form-field-error mat-mdc-form-field-bottom-align">{{ errorMessage }}</div>
    </div>
  </div>
</div>
`, dependencies: [{ kind: "directive", type: NgClass6, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgIf5, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
  }
};
i013.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i013, type: MatDynamicFormInputWrapperComponent, decorators: [{
  type: Component7,
  args: [{ standalone: true, selector: "mat-dynamic-form-input-wrapper", imports: [NgClass6, NgIf5], template: `<div
  class="mat-mdc-form-field mat-mdc-form-field-wrapper"
  [ngClass]="{ 'mdc-text-field--disabled': disabled, 'mdc-text-field--invalid': invalid }"
>
  <div class="mat-mdc-form-field-input-wrapper">
    <label *ngIf="label" class="mat-mdc-form-field-input-label mat-mdc-floating-label mdc-floating-label" [for]="inputId"
      >{{ label }}<span *ngIf="required">*</span></label
    >
    <ng-content />
  </div>
  <div class="mat-mdc-form-field-subscript-wrapper mat-mdc-form-field-bottom-align">
    <div *ngIf="invalid" class="mat-mdc-form-field-error-wrapper">
      <div class="mat-mdc-form-field-error mat-mdc-form-field-bottom-align">{{ errorMessage }}</div>
    </div>
  </div>
</div>
` }]
}], propDecorators: { label: [{
  type: Input2
}], inputId: [{
  type: Input2
}], required: [{
  type: Input2
}], disabled: [{
  type: Input2,
  args: [{ required: true }]
}], invalid: [{
  type: Input2,
  args: [{ required: true }]
}], errorMessage: [{
  type: Input2,
  args: [{ required: true }]
}] } });

// lib/dynamic-form-input/dynamic-form-checkbox/dynamic-form-checkbox.component.mjs
import { NgIf as NgIf6 } from "@angular/common";
import { Component as Component8 } from "@angular/core";
import { ReactiveFormsModule } from "@angular/forms";
import { MatCheckboxModule } from "@angular/material/checkbox";
import { DynamicFormInputBase } from "@dynamic-forms/core";
import * as i014 from "@angular/core";
import * as i16 from "@dynamic-forms/core";
import * as i23 from "@angular/forms";
import * as i32 from "@angular/material/checkbox";
var MatDynamicFormCheckboxComponent = class _MatDynamicFormCheckboxComponent extends DynamicFormInputBase {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i014.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i014, type: _MatDynamicFormCheckboxComponent, deps: [{ token: i16.DynamicFormValidationService }], target: i014.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i014.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormCheckboxComponent, isStandalone: true, selector: "mat-dynamic-form-checkbox", usesInheritance: true, ngImport: i014, template: '<mat-dynamic-form-input-wrapper [disabled]="disabled" [invalid]="showErrors" [errorMessage]="showErrors ? errorMessage : null">\n  <mat-checkbox\n    color="primary"\n    [id]="inputId"\n    [indeterminate]="input?.indeterminate"\n    [required]="validation?.required"\n    [formControl]="control"\n    >{{ template.label }}<span *ngIf="validation?.required">*</span></mat-checkbox\n  >\n</mat-dynamic-form-input-wrapper>\n', dependencies: [{ kind: "directive", type: NgIf6, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i23.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i23.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i23.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: MatDynamicFormInputWrapperComponent, selector: "mat-dynamic-form-input-wrapper", inputs: ["label", "inputId", "required", "disabled", "invalid", "errorMessage"] }, { kind: "ngmodule", type: MatCheckboxModule }, { kind: "component", type: i32.MatCheckbox, selector: "mat-checkbox", inputs: ["aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "disableRipple", "tabIndex", "color", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }] });
  }
};
i014.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i014, type: MatDynamicFormCheckboxComponent, decorators: [{
  type: Component8,
  args: [{ standalone: true, selector: "mat-dynamic-form-checkbox", imports: [NgIf6, ReactiveFormsModule, MatDynamicFormInputWrapperComponent, MatCheckboxModule], template: '<mat-dynamic-form-input-wrapper [disabled]="disabled" [invalid]="showErrors" [errorMessage]="showErrors ? errorMessage : null">\n  <mat-checkbox\n    color="primary"\n    [id]="inputId"\n    [indeterminate]="input?.indeterminate"\n    [required]="validation?.required"\n    [formControl]="control"\n    >{{ template.label }}<span *ngIf="validation?.required">*</span></mat-checkbox\n  >\n</mat-dynamic-form-input-wrapper>\n' }]
}], ctorParameters: () => [{ type: i16.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-checkbox/dynamic-form-checkbox-type.mjs
var matDynamicFormCheckboxType = {
  type: "checkbox",
  component: MatDynamicFormCheckboxComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-combobox/dynamic-form-combobox.component.mjs
import { AsyncPipe, NgFor as NgFor3, NgIf as NgIf7 } from "@angular/common";
import { Component as Component9 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule2 } from "@angular/forms";
import { MatAutocompleteModule } from "@angular/material/autocomplete";
import { MatFormFieldModule } from "@angular/material/form-field";
import { MatInputModule } from "@angular/material/input";
import { DynamicFormElementComponent as DynamicFormElementComponent2, DynamicFormInputBase as DynamicFormInputBase2 } from "@dynamic-forms/core";
import { map, startWith } from "rxjs/operators";
import * as i015 from "@angular/core";
import * as i17 from "@dynamic-forms/core";
import * as i24 from "@angular/forms";
import * as i33 from "@angular/material/form-field";
import * as i42 from "@angular/material/input";
import * as i5 from "@angular/material/autocomplete";
import * as i6 from "@angular/material/core";
var MatDynamicFormComboboxComponent = class _MatDynamicFormComboboxComponent extends DynamicFormInputBase2 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  ngOnInit() {
    this.filteredOptions = this.control.valueChanges.pipe(startWith(""), map((value) => this.getFilteredOptions(value)));
  }
  getFilteredOptions(value) {
    const valueNormalized = value ? value.toUpperCase() : null;
    return valueNormalized ? this.input.options?.filter((option) => option.toUpperCase().includes(valueNormalized)) : this.input.options;
  }
  static {
    this.ɵfac = i015.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i015, type: _MatDynamicFormComboboxComponent, deps: [{ token: i17.DynamicFormValidationService }], target: i015.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i015.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormComboboxComponent, isStandalone: true, selector: "mat-dynamic-form-combobox", usesInheritance: true, ngImport: i015, template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    type="text"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [matAutocomplete]="auto"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <mat-autocomplete #auto="matAutocomplete">
    <mat-option *ngFor="let option of filteredOptions | async" [value]="option">{{ option }}</mat-option>
  </mat-autocomplete>
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
`, dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: NgIf7, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgFor3, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "ngmodule", type: ReactiveFormsModule2 }, { kind: "directive", type: i24.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i24.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i24.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i24.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: DynamicFormElementComponent2, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "component", type: i33.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i33.MatLabel, selector: "mat-label" }, { kind: "directive", type: i33.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i33.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i33.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i33.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i42.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "ngmodule", type: MatAutocompleteModule }, { kind: "component", type: i5.MatAutocomplete, selector: "mat-autocomplete", inputs: ["aria-label", "aria-labelledby", "displayWith", "autoActiveFirstOption", "autoSelectActiveOption", "requireSelection", "panelWidth", "disableRipple", "class", "hideSingleSelectionIndicator"], outputs: ["optionSelected", "opened", "closed", "optionActivated"], exportAs: ["matAutocomplete"] }, { kind: "component", type: i6.MatOption, selector: "mat-option", inputs: ["value", "id", "disabled"], outputs: ["onSelectionChange"], exportAs: ["matOption"] }, { kind: "directive", type: i5.MatAutocompleteTrigger, selector: "input[matAutocomplete], textarea[matAutocomplete]", inputs: ["matAutocomplete", "matAutocompletePosition", "matAutocompleteConnectedTo", "autocomplete", "matAutocompleteDisabled"], exportAs: ["matAutocompleteTrigger"] }] });
  }
};
i015.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i015, type: MatDynamicFormComboboxComponent, decorators: [{
  type: Component9,
  args: [{ standalone: true, selector: "mat-dynamic-form-combobox", imports: [
    AsyncPipe,
    NgIf7,
    NgFor3,
    ReactiveFormsModule2,
    DynamicFormElementComponent2,
    MatFormFieldModule,
    MatInputModule,
    MatAutocompleteModule
  ], template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    type="text"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [matAutocomplete]="auto"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <mat-autocomplete #auto="matAutocomplete">
    <mat-option *ngFor="let option of filteredOptions | async" [value]="option">{{ option }}</mat-option>
  </mat-autocomplete>
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
` }]
}], ctorParameters: () => [{ type: i17.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-combobox/dynamic-form-combobox-type.mjs
var matDynamicFormComboboxType = {
  type: "combobox",
  component: MatDynamicFormComboboxComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-datepicker/dynamic-form-datepicker.component.mjs
import { NgIf as NgIf8 } from "@angular/common";
import { Component as Component10 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule3 } from "@angular/forms";
import { MatDatepickerModule } from "@angular/material/datepicker";
import { MatFormFieldModule as MatFormFieldModule2 } from "@angular/material/form-field";
import { MatInputModule as MatInputModule2 } from "@angular/material/input";
import { DynamicFormElementComponent as DynamicFormElementComponent3, DynamicFormInputBase as DynamicFormInputBase3 } from "@dynamic-forms/core";
import * as i016 from "@angular/core";
import * as i18 from "@dynamic-forms/core";
import * as i25 from "@angular/forms";
import * as i34 from "@angular/material/form-field";
import * as i43 from "@angular/material/input";
import * as i52 from "@angular/material/datepicker";
var MatDynamicFormDatepickerComponent = class _MatDynamicFormDatepickerComponent extends DynamicFormInputBase3 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i016.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i016, type: _MatDynamicFormDatepickerComponent, deps: [{ token: i18.DynamicFormValidationService }], target: i016.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i016.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormDatepickerComponent, isStandalone: true, selector: "mat-dynamic-form-datepicker", usesInheritance: true, ngImport: i016, template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating" [class.suffixes-flex]="suffixAddOn">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    [matDatepicker]="datepicker"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [min]="input.minDate"
    [max]="input.maxDate"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <mat-datepicker-toggle matSuffix [for]="datepicker" [disabled]="control.disabled || readonly" />
  <mat-datepicker #datepicker [disabled]="control.disabled" />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
`, dependencies: [{ kind: "directive", type: NgIf8, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule3 }, { kind: "directive", type: i25.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i25.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i25.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i25.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: DynamicFormElementComponent3, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatFormFieldModule2 }, { kind: "component", type: i34.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i34.MatLabel, selector: "mat-label" }, { kind: "directive", type: i34.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i34.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i34.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i34.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatInputModule2 }, { kind: "directive", type: i43.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "ngmodule", type: MatDatepickerModule }, { kind: "component", type: i52.MatDatepicker, selector: "mat-datepicker", exportAs: ["matDatepicker"] }, { kind: "directive", type: i52.MatDatepickerInput, selector: "input[matDatepicker]", inputs: ["matDatepicker", "min", "max", "matDatepickerFilter"], exportAs: ["matDatepickerInput"] }, { kind: "component", type: i52.MatDatepickerToggle, selector: "mat-datepicker-toggle", inputs: ["for", "tabIndex", "aria-label", "disabled", "disableRipple"], exportAs: ["matDatepickerToggle"] }] });
  }
};
i016.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i016, type: MatDynamicFormDatepickerComponent, decorators: [{
  type: Component10,
  args: [{ standalone: true, selector: "mat-dynamic-form-datepicker", imports: [NgIf8, ReactiveFormsModule3, DynamicFormElementComponent3, MatFormFieldModule2, MatInputModule2, MatDatepickerModule], template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating" [class.suffixes-flex]="suffixAddOn">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    [matDatepicker]="datepicker"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [min]="input.minDate"
    [max]="input.maxDate"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <mat-datepicker-toggle matSuffix [for]="datepicker" [disabled]="control.disabled || readonly" />
  <mat-datepicker #datepicker [disabled]="control.disabled" />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
` }]
}], ctorParameters: () => [{ type: i18.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-datepicker/dynamic-form-datepicker-type.mjs
var matDynamicFormDatepickerType = {
  type: "datepicker",
  component: MatDynamicFormDatepickerComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-file/dynamic-form-file.component.mjs
import { NgIf as NgIf9 } from "@angular/common";
import { Component as Component11, ViewChild as ViewChild2 } from "@angular/core";
import { NgControl, ReactiveFormsModule as ReactiveFormsModule4 } from "@angular/forms";
import { MatFormFieldModule as MatFormFieldModule3 } from "@angular/material/form-field";
import { MatInput as MatInput3, MatInputModule as MatInputModule3 } from "@angular/material/input";
import { DynamicFormElementComponent as DynamicFormElementComponent4, DynamicFormFileBase, DynamicFormFileDirective } from "@dynamic-forms/core";
import * as i017 from "@angular/core";
import * as i19 from "@dynamic-forms/core";
import * as i26 from "@angular/forms";
import * as i35 from "@angular/material/input";
import * as i44 from "@angular/material/form-field";
var MatDynamicFormFileComponent = class _MatDynamicFormFileComponent extends DynamicFormFileBase {
  constructor(builder, validationService) {
    super(builder, validationService);
    this.builder = builder;
    this.validationService = validationService;
  }
  ngOnInit() {
    super.ngOnInit();
    this._matInput.ngControl = this._ngControl;
    this._matInput["_errorStateTracker"].ngControl = this._ngControl;
  }
  static {
    this.ɵfac = i017.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i017, type: _MatDynamicFormFileComponent, deps: [{ token: i19.DynamicFormBuilder }, { token: i19.DynamicFormValidationService }], target: i017.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i017.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormFileComponent, isStandalone: true, selector: "mat-dynamic-form-file", viewQueries: [{ propertyName: "_matInput", first: true, predicate: MatInput3, descendants: true, static: true }, { propertyName: "_ngControl", first: true, predicate: NgControl, descendants: true, static: true }], usesInheritance: true, ngImport: i017, template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating" [class.suffixes-flex]="suffixAddOn">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    readonly
    [id]="inputId"
    [placeholder]="input.placeholder"
    [value]="fileDirective.fileNamesAsText || ''"
    [disabled]="control.disabled"
    (blur)="control.markAsTouched()"
  />
  <input
    #fileDirective="dynamicFormFile"
    fileControl
    dynamicFormFile
    [acceptFiles]="input.accept"
    [multipleFiles]="input.multiple"
    [formControl]="control"
  />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element matSuffix [element]="uploadAction" />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
`, dependencies: [{ kind: "directive", type: NgIf9, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule4 }, { kind: "directive", type: i26.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i26.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i26.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "directive", type: DynamicFormFileDirective, selector: "[dynamicFormFile]", inputs: ["acceptFiles", "multipleFiles"], exportAs: ["dynamicFormFile"] }, { kind: "component", type: DynamicFormElementComponent4, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatInputModule3 }, { kind: "directive", type: i35.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i44.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i44.MatLabel, selector: "mat-label" }, { kind: "directive", type: i44.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i44.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i44.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i44.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatFormFieldModule3 }] });
  }
};
i017.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i017, type: MatDynamicFormFileComponent, decorators: [{
  type: Component11,
  args: [{ standalone: true, selector: "mat-dynamic-form-file", imports: [NgIf9, ReactiveFormsModule4, DynamicFormFileDirective, DynamicFormElementComponent4, MatInputModule3, MatFormFieldModule3], template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating" [class.suffixes-flex]="suffixAddOn">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    readonly
    [id]="inputId"
    [placeholder]="input.placeholder"
    [value]="fileDirective.fileNamesAsText || ''"
    [disabled]="control.disabled"
    (blur)="control.markAsTouched()"
  />
  <input
    #fileDirective="dynamicFormFile"
    fileControl
    dynamicFormFile
    [acceptFiles]="input.accept"
    [multipleFiles]="input.multiple"
    [formControl]="control"
  />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element matSuffix [element]="uploadAction" />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
` }]
}], ctorParameters: () => [{ type: i19.DynamicFormBuilder }, { type: i19.DynamicFormValidationService }], propDecorators: { _matInput: [{
  type: ViewChild2,
  args: [MatInput3, { static: true }]
}], _ngControl: [{
  type: ViewChild2,
  args: [NgControl, { static: true }]
}] } });

// lib/dynamic-form-input/dynamic-form-file/dynamic-form-file-type.mjs
var matDynamicFormFileType = {
  type: "file",
  component: MatDynamicFormFileComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-numberbox/dynamic-form-numberbox.component.mjs
import { NgIf as NgIf10 } from "@angular/common";
import { Component as Component12 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule5 } from "@angular/forms";
import { MatFormFieldModule as MatFormFieldModule4 } from "@angular/material/form-field";
import { MatInputModule as MatInputModule4 } from "@angular/material/input";
import { DynamicFormElementComponent as DynamicFormElementComponent5, DynamicFormInputBase as DynamicFormInputBase4 } from "@dynamic-forms/core";
import * as i018 from "@angular/core";
import * as i110 from "@dynamic-forms/core";
import * as i27 from "@angular/forms";
import * as i36 from "@angular/material/form-field";
import * as i45 from "@angular/material/input";
var MatDynamicFormNumberboxComponent = class _MatDynamicFormNumberboxComponent extends DynamicFormInputBase4 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i018.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i018, type: _MatDynamicFormNumberboxComponent, deps: [{ token: i110.DynamicFormValidationService }], target: i018.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i018.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormNumberboxComponent, isStandalone: true, selector: "mat-dynamic-form-numberbox", usesInheritance: true, ngImport: i018, template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    type="number"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
`, dependencies: [{ kind: "directive", type: NgIf10, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule5 }, { kind: "directive", type: i27.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i27.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i27.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i27.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i27.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: DynamicFormElementComponent5, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatFormFieldModule4 }, { kind: "component", type: i36.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i36.MatLabel, selector: "mat-label" }, { kind: "directive", type: i36.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i36.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i36.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i36.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatInputModule4 }, { kind: "directive", type: i45.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }] });
  }
};
i018.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i018, type: MatDynamicFormNumberboxComponent, decorators: [{
  type: Component12,
  args: [{ standalone: true, selector: "mat-dynamic-form-numberbox", imports: [NgIf10, ReactiveFormsModule5, DynamicFormElementComponent5, MatFormFieldModule4, MatInputModule4], template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    type="number"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
` }]
}], ctorParameters: () => [{ type: i110.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-numberbox/dynamic-form-numberbox-type.mjs
var matDynamicFormNumberboxType = {
  type: "numberbox",
  component: MatDynamicFormNumberboxComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-radio/dynamic-form-radio.component.mjs
import { NgFor as NgFor4 } from "@angular/common";
import { Component as Component13 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule6 } from "@angular/forms";
import { MatRadioModule } from "@angular/material/radio";
import { DynamicFormInputBase as DynamicFormInputBase5 } from "@dynamic-forms/core";
import * as i019 from "@angular/core";
import * as i111 from "@dynamic-forms/core";
import * as i28 from "@angular/forms";
import * as i37 from "@angular/material/radio";
var MatDynamicFormRadioComponent = class _MatDynamicFormRadioComponent extends DynamicFormInputBase5 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i019.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i019, type: _MatDynamicFormRadioComponent, deps: [{ token: i111.DynamicFormValidationService }], target: i019.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i019.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormRadioComponent, isStandalone: true, selector: "mat-dynamic-form-radio", usesInheritance: true, ngImport: i019, template: `<mat-dynamic-form-input-wrapper
  [label]="template.label"
  [required]="validation?.required"
  [disabled]="disabled"
  [invalid]="showErrors"
  [errorMessage]="showErrors ? errorMessage : null"
>
  <mat-radio-group [formControl]="control">
    <ng-container *ngFor="let option of input.options; let i = index">
      <mat-radio-button color="primary" [id]="inputId + '-' + i" [value]="option.value" [disabled]="option.disabled">{{
        option.label
      }}</mat-radio-button>
    </ng-container>
  </mat-radio-group>
</mat-dynamic-form-input-wrapper>
`, dependencies: [{ kind: "directive", type: NgFor4, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "ngmodule", type: ReactiveFormsModule6 }, { kind: "directive", type: i28.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i28.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: MatDynamicFormInputWrapperComponent, selector: "mat-dynamic-form-input-wrapper", inputs: ["label", "inputId", "required", "disabled", "invalid", "errorMessage"] }, { kind: "ngmodule", type: MatRadioModule }, { kind: "directive", type: i37.MatRadioGroup, selector: "mat-radio-group", inputs: ["color", "name", "labelPosition", "value", "selected", "disabled", "required"], outputs: ["change"], exportAs: ["matRadioGroup"] }, { kind: "component", type: i37.MatRadioButton, selector: "mat-radio-button", inputs: ["id", "name", "aria-label", "aria-labelledby", "aria-describedby", "disableRipple", "tabIndex", "checked", "value", "labelPosition", "disabled", "required", "color"], outputs: ["change"], exportAs: ["matRadioButton"] }] });
  }
};
i019.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i019, type: MatDynamicFormRadioComponent, decorators: [{
  type: Component13,
  args: [{ standalone: true, selector: "mat-dynamic-form-radio", imports: [NgFor4, ReactiveFormsModule6, MatDynamicFormInputWrapperComponent, MatRadioModule], template: `<mat-dynamic-form-input-wrapper
  [label]="template.label"
  [required]="validation?.required"
  [disabled]="disabled"
  [invalid]="showErrors"
  [errorMessage]="showErrors ? errorMessage : null"
>
  <mat-radio-group [formControl]="control">
    <ng-container *ngFor="let option of input.options; let i = index">
      <mat-radio-button color="primary" [id]="inputId + '-' + i" [value]="option.value" [disabled]="option.disabled">{{
        option.label
      }}</mat-radio-button>
    </ng-container>
  </mat-radio-group>
</mat-dynamic-form-input-wrapper>
` }]
}], ctorParameters: () => [{ type: i111.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-radio/dynamic-form-radio-type.mjs
var matDynamicFormRadioType = {
  type: "radio",
  component: MatDynamicFormRadioComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-select/dynamic-form-select.component.mjs
import { NgFor as NgFor5, NgIf as NgIf11 } from "@angular/common";
import { Component as Component14 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule7 } from "@angular/forms";
import { MatFormFieldModule as MatFormFieldModule5 } from "@angular/material/form-field";
import { MatSelectModule } from "@angular/material/select";
import { DynamicFormElementComponent as DynamicFormElementComponent6, DynamicFormInputBase as DynamicFormInputBase6 } from "@dynamic-forms/core";
import * as i020 from "@angular/core";
import * as i112 from "@dynamic-forms/core";
import * as i29 from "@angular/forms";
import * as i38 from "@angular/material/form-field";
import * as i46 from "@angular/material/select";
import * as i53 from "@angular/material/core";
var MatDynamicFormSelectComponent = class _MatDynamicFormSelectComponent extends DynamicFormInputBase6 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i020.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i020, type: _MatDynamicFormSelectComponent, deps: [{ token: i112.DynamicFormValidationService }], target: i020.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i020.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormSelectComponent, isStandalone: true, selector: "mat-dynamic-form-select", usesInheritance: true, ngImport: i020, template: `<mat-form-field *ngIf="!input.multiple; else multiSelect" appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <mat-select [id]="inputId" [placeholder]="input.placeholder" [required]="validation?.required" [formControl]="control">
    <ng-container *ngFor="let option of input.options">
      <ng-container *ngIf="!option.items; else optionGroup">
        <mat-option [value]="option.value" [disabled]="option.disabled">{{ option.label }}</mat-option>
      </ng-container>
      <ng-template #optionGroup>
        <mat-optgroup [label]="option.label" [disabled]="option.disabled">
          <ng-container *ngFor="let optionItem of option.items">
            <mat-option [value]="optionItem.value" [disabled]="optionItem.disabled">{{ optionItem.label }}</mat-option>
          </ng-container>
        </mat-optgroup>
      </ng-template>
    </ng-container>
  </mat-select>
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint [align]="'start'">{{ hints?.hintStart }}</mat-hint>
  <mat-hint [align]="'end'">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
<ng-template #multiSelect>
  <mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
    <mat-label>{{ template.label }}</mat-label>
    <mat-select multiple [id]="inputId" [placeholder]="input.placeholder" [required]="validation?.required" [formControl]="control">
      <ng-container *ngFor="let option of input.options">
        <ng-container *ngIf="!option.items; else optionGroup">
          <mat-option [value]="option.value" [disabled]="option.disabled">{{ option.label }}</mat-option>
        </ng-container>
        <ng-template #optionGroup>
          <mat-optgroup [label]="option.label" [disabled]="option.disabled">
            <ng-container *ngFor="let optionItem of option.items">
              <mat-option [value]="optionItem.value" [disabled]="optionItem.disabled">{{ optionItem.label }}</mat-option>
            </ng-container>
          </mat-optgroup>
        </ng-template>
      </ng-container>
    </mat-select>
    <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
    <dynamic-form-element
      *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
      matPrefix
      [element]="prefixAddOn"
    />
    <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
    <dynamic-form-element
      *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
      matSuffix
      [element]="suffixAddOn"
    />
    <mat-hint [align]="'start'">{{ hints?.hintStart }}</mat-hint>
    <mat-hint [align]="'end'">{{ hints?.hintEnd }}</mat-hint>
    <mat-error>{{ errorMessage }}</mat-error>
  </mat-form-field>
</ng-template>
`, dependencies: [{ kind: "directive", type: NgFor5, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgIf11, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule7 }, { kind: "directive", type: i29.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i29.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i29.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: DynamicFormElementComponent6, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatFormFieldModule5 }, { kind: "component", type: i38.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i38.MatLabel, selector: "mat-label" }, { kind: "directive", type: i38.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i38.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i38.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i38.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatSelectModule }, { kind: "component", type: i46.MatSelect, selector: "mat-select", inputs: ["aria-describedby", "panelClass", "disabled", "disableRipple", "tabIndex", "hideSingleSelectionIndicator", "placeholder", "required", "multiple", "disableOptionCentering", "compareWith", "value", "aria-label", "aria-labelledby", "errorStateMatcher", "typeaheadDebounceInterval", "sortComparator", "id", "panelWidth"], outputs: ["openedChange", "opened", "closed", "selectionChange", "valueChange"], exportAs: ["matSelect"] }, { kind: "component", type: i53.MatOption, selector: "mat-option", inputs: ["value", "id", "disabled"], outputs: ["onSelectionChange"], exportAs: ["matOption"] }, { kind: "component", type: i53.MatOptgroup, selector: "mat-optgroup", inputs: ["label", "disabled"], exportAs: ["matOptgroup"] }] });
  }
};
i020.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i020, type: MatDynamicFormSelectComponent, decorators: [{
  type: Component14,
  args: [{ standalone: true, selector: "mat-dynamic-form-select", imports: [NgFor5, NgIf11, ReactiveFormsModule7, DynamicFormElementComponent6, MatFormFieldModule5, MatSelectModule], template: `<mat-form-field *ngIf="!input.multiple; else multiSelect" appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <mat-select [id]="inputId" [placeholder]="input.placeholder" [required]="validation?.required" [formControl]="control">
    <ng-container *ngFor="let option of input.options">
      <ng-container *ngIf="!option.items; else optionGroup">
        <mat-option [value]="option.value" [disabled]="option.disabled">{{ option.label }}</mat-option>
      </ng-container>
      <ng-template #optionGroup>
        <mat-optgroup [label]="option.label" [disabled]="option.disabled">
          <ng-container *ngFor="let optionItem of option.items">
            <mat-option [value]="optionItem.value" [disabled]="optionItem.disabled">{{ optionItem.label }}</mat-option>
          </ng-container>
        </mat-optgroup>
      </ng-template>
    </ng-container>
  </mat-select>
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint [align]="'start'">{{ hints?.hintStart }}</mat-hint>
  <mat-hint [align]="'end'">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
<ng-template #multiSelect>
  <mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
    <mat-label>{{ template.label }}</mat-label>
    <mat-select multiple [id]="inputId" [placeholder]="input.placeholder" [required]="validation?.required" [formControl]="control">
      <ng-container *ngFor="let option of input.options">
        <ng-container *ngIf="!option.items; else optionGroup">
          <mat-option [value]="option.value" [disabled]="option.disabled">{{ option.label }}</mat-option>
        </ng-container>
        <ng-template #optionGroup>
          <mat-optgroup [label]="option.label" [disabled]="option.disabled">
            <ng-container *ngFor="let optionItem of option.items">
              <mat-option [value]="optionItem.value" [disabled]="optionItem.disabled">{{ optionItem.label }}</mat-option>
            </ng-container>
          </mat-optgroup>
        </ng-template>
      </ng-container>
    </mat-select>
    <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
    <dynamic-form-element
      *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
      matPrefix
      [element]="prefixAddOn"
    />
    <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
    <dynamic-form-element
      *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
      matSuffix
      [element]="suffixAddOn"
    />
    <mat-hint [align]="'start'">{{ hints?.hintStart }}</mat-hint>
    <mat-hint [align]="'end'">{{ hints?.hintEnd }}</mat-hint>
    <mat-error>{{ errorMessage }}</mat-error>
  </mat-form-field>
</ng-template>
` }]
}], ctorParameters: () => [{ type: i112.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-select/dynamic-form-select-type.mjs
var matDynamicFormSelectType = {
  type: "select",
  component: MatDynamicFormSelectComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-switch/dynamic-form-switch.component.mjs
import { NgIf as NgIf12 } from "@angular/common";
import { Component as Component15 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule8 } from "@angular/forms";
import { MatSlideToggleModule } from "@angular/material/slide-toggle";
import { DynamicFormInputBase as DynamicFormInputBase7 } from "@dynamic-forms/core";
import * as i021 from "@angular/core";
import * as i113 from "@dynamic-forms/core";
import * as i210 from "@angular/forms";
import * as i39 from "@angular/material/slide-toggle";
var MatDynamicFormSwitchComponent = class _MatDynamicFormSwitchComponent extends DynamicFormInputBase7 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i021.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i021, type: _MatDynamicFormSwitchComponent, deps: [{ token: i113.DynamicFormValidationService }], target: i021.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i021.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormSwitchComponent, isStandalone: true, selector: "mat-dynamic-form-switch", usesInheritance: true, ngImport: i021, template: '<mat-dynamic-form-input-wrapper [disabled]="disabled" [invalid]="showErrors" [errorMessage]="showErrors ? errorMessage : null">\n  <mat-slide-toggle color="primary" [id]="inputId" [required]="validation?.required" [formControl]="control"\n    >{{ template.label }}<span *ngIf="validation?.required">*</span></mat-slide-toggle\n  >\n</mat-dynamic-form-input-wrapper>\n', dependencies: [{ kind: "directive", type: NgIf12, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule8 }, { kind: "directive", type: i210.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i210.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i210.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: MatDynamicFormInputWrapperComponent, selector: "mat-dynamic-form-input-wrapper", inputs: ["label", "inputId", "required", "disabled", "invalid", "errorMessage"] }, { kind: "ngmodule", type: MatSlideToggleModule }, { kind: "component", type: i39.MatSlideToggle, selector: "mat-slide-toggle", inputs: ["name", "id", "labelPosition", "aria-label", "aria-labelledby", "aria-describedby", "required", "color", "disabled", "disableRipple", "tabIndex", "checked", "hideIcon"], outputs: ["change", "toggleChange"], exportAs: ["matSlideToggle"] }] });
  }
};
i021.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i021, type: MatDynamicFormSwitchComponent, decorators: [{
  type: Component15,
  args: [{ standalone: true, selector: "mat-dynamic-form-switch", imports: [NgIf12, ReactiveFormsModule8, MatDynamicFormInputWrapperComponent, MatSlideToggleModule], template: '<mat-dynamic-form-input-wrapper [disabled]="disabled" [invalid]="showErrors" [errorMessage]="showErrors ? errorMessage : null">\n  <mat-slide-toggle color="primary" [id]="inputId" [required]="validation?.required" [formControl]="control"\n    >{{ template.label }}<span *ngIf="validation?.required">*</span></mat-slide-toggle\n  >\n</mat-dynamic-form-input-wrapper>\n' }]
}], ctorParameters: () => [{ type: i113.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-switch/dynamic-form-switch-type.mjs
var matDynamicFormSwitchType = {
  type: "switch",
  component: MatDynamicFormSwitchComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-textarea/dynamic-form-textarea.component.mjs
import { NgIf as NgIf13 } from "@angular/common";
import { Component as Component16 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule9 } from "@angular/forms";
import { MatFormFieldModule as MatFormFieldModule6 } from "@angular/material/form-field";
import { MatInputModule as MatInputModule5 } from "@angular/material/input";
import { DynamicFormElementComponent as DynamicFormElementComponent7, DynamicFormInputBase as DynamicFormInputBase8 } from "@dynamic-forms/core";
import * as i022 from "@angular/core";
import * as i114 from "@dynamic-forms/core";
import * as i211 from "@angular/forms";
import * as i310 from "@angular/material/form-field";
import * as i47 from "@angular/material/input";
import * as i54 from "@angular/cdk/text-field";
var MatDynamicFormTextareaComponent = class _MatDynamicFormTextareaComponent extends DynamicFormInputBase8 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i022.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i022, type: _MatDynamicFormTextareaComponent, deps: [{ token: i114.DynamicFormValidationService }], target: i022.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i022.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormTextareaComponent, isStandalone: true, selector: "mat-dynamic-form-textarea", usesInheritance: true, ngImport: i022, template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <textarea
    #autosize="cdkTextareaAutosize"
    matInput
    cdkTextareaAutosize
    cdkAutosizeMinRows="1"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  >
  </textarea>
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
`, dependencies: [{ kind: "directive", type: NgIf13, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule9 }, { kind: "directive", type: i211.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i211.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i211.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i211.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: DynamicFormElementComponent7, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatFormFieldModule6 }, { kind: "component", type: i310.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i310.MatLabel, selector: "mat-label" }, { kind: "directive", type: i310.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i310.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i310.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i310.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatInputModule5 }, { kind: "directive", type: i47.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "directive", type: i54.CdkTextareaAutosize, selector: "textarea[cdkTextareaAutosize]", inputs: ["cdkAutosizeMinRows", "cdkAutosizeMaxRows", "cdkTextareaAutosize", "placeholder"], exportAs: ["cdkTextareaAutosize"] }] });
  }
};
i022.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i022, type: MatDynamicFormTextareaComponent, decorators: [{
  type: Component16,
  args: [{ standalone: true, selector: "mat-dynamic-form-textarea", imports: [NgIf13, ReactiveFormsModule9, DynamicFormElementComponent7, MatFormFieldModule6, MatInputModule5], template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <textarea
    #autosize="cdkTextareaAutosize"
    matInput
    cdkTextareaAutosize
    cdkAutosizeMinRows="1"
    [id]="inputId"
    [placeholder]="input.placeholder"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  >
  </textarea>
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
` }]
}], ctorParameters: () => [{ type: i114.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-textarea/dynamic-form-textarea-type.mjs
var matDynamicFormTextareaType = {
  type: "textarea",
  component: MatDynamicFormTextareaComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-textbox/dynamic-form-textbox.component.mjs
import { NgIf as NgIf14 } from "@angular/common";
import { Component as Component17 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule10 } from "@angular/forms";
import { MatFormFieldModule as MatFormFieldModule7 } from "@angular/material/form-field";
import { MatInputModule as MatInputModule6 } from "@angular/material/input";
import { DynamicFormElementComponent as DynamicFormElementComponent8, DynamicFormInputBase as DynamicFormInputBase9 } from "@dynamic-forms/core";
import * as i023 from "@angular/core";
import * as i115 from "@dynamic-forms/core";
import * as i212 from "@angular/forms";
import * as i311 from "@angular/material/form-field";
import * as i48 from "@angular/material/input";
var MatDynamicFormTextboxComponent = class _MatDynamicFormTextboxComponent extends DynamicFormInputBase9 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i023.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i023, type: _MatDynamicFormTextboxComponent, deps: [{ token: i115.DynamicFormValidationService }], target: i023.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i023.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormTextboxComponent, isStandalone: true, selector: "mat-dynamic-form-textbox", usesInheritance: true, ngImport: i023, template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    [id]="inputId"
    [type]="input.inputTypeForced || input.inputType"
    [placeholder]="input.placeholder"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
`, dependencies: [{ kind: "directive", type: NgIf14, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule10 }, { kind: "directive", type: i212.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i212.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i212.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i212.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: DynamicFormElementComponent8, selector: "dynamic-form-element" }, { kind: "ngmodule", type: MatFormFieldModule7 }, { kind: "component", type: i311.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i311.MatLabel, selector: "mat-label" }, { kind: "directive", type: i311.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { kind: "directive", type: i311.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i311.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i311.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatInputModule6 }, { kind: "directive", type: i48.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }] });
  }
};
i023.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i023, type: MatDynamicFormTextboxComponent, decorators: [{
  type: Component17,
  args: [{ standalone: true, selector: "mat-dynamic-form-textbox", imports: [NgIf14, ReactiveFormsModule10, DynamicFormElementComponent8, MatFormFieldModule7, MatInputModule6], template: `<mat-form-field appearance="fill" color="primary" [floatLabel]="template.labelFloating">
  <mat-label>{{ template.label }}</mat-label>
  <input
    matInput
    [id]="inputId"
    [type]="input.inputTypeForced || input.inputType"
    [placeholder]="input.placeholder"
    [readonly]="readonly"
    [required]="validation?.required"
    [formControl]="control"
  />
  <dynamic-form-element *ngIf="prefixAddOn?.classType === 'element' && !prefixAddOn.hidden" matTextPrefix [element]="prefixAddOn" />
  <dynamic-form-element
    *ngIf="prefixAddOn && prefixAddOn.classType !== 'element' && !prefixAddOn.hidden"
    matPrefix
    [element]="prefixAddOn"
  />
  <dynamic-form-element *ngIf="suffixAddOn?.classType === 'element' && !suffixAddOn.hidden" matTextSuffix [element]="suffixAddOn" />
  <dynamic-form-element
    *ngIf="suffixAddOn && suffixAddOn.classType !== 'element' && !suffixAddOn.hidden"
    matSuffix
    [element]="suffixAddOn"
  />
  <mat-hint align="start">{{ hints?.hintStart }}</mat-hint>
  <mat-hint align="end">{{ hints?.hintEnd }}</mat-hint>
  <mat-error>{{ errorMessage }}</mat-error>
</mat-form-field>
` }]
}], ctorParameters: () => [{ type: i115.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-textbox/dynamic-form-textbox-type.mjs
var matDynamicFormTextboxType = {
  type: "textbox",
  component: MatDynamicFormTextboxComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-toggle/dynamic-form-toggle.component.mjs
import { NgFor as NgFor6 } from "@angular/common";
import { Component as Component18 } from "@angular/core";
import { ReactiveFormsModule as ReactiveFormsModule11 } from "@angular/forms";
import { MatButtonToggleModule } from "@angular/material/button-toggle";
import { DynamicFormInputBase as DynamicFormInputBase10 } from "@dynamic-forms/core";
import * as i024 from "@angular/core";
import * as i116 from "@dynamic-forms/core";
import * as i213 from "@angular/forms";
import * as i312 from "@angular/material/button-toggle";
var MatDynamicFormToggleComponent = class _MatDynamicFormToggleComponent extends DynamicFormInputBase10 {
  constructor(validationService) {
    super(validationService);
    this.validationService = validationService;
  }
  static {
    this.ɵfac = i024.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i024, type: _MatDynamicFormToggleComponent, deps: [{ token: i116.DynamicFormValidationService }], target: i024.ɵɵFactoryTarget.Component });
  }
  static {
    this.ɵcmp = i024.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.0.0-next.6", type: _MatDynamicFormToggleComponent, isStandalone: true, selector: "mat-dynamic-form-toggle", usesInheritance: true, ngImport: i024, template: `<mat-dynamic-form-input-wrapper
  [inputId]="inputId"
  [label]="template.label"
  [required]="validation?.required"
  [disabled]="disabled"
  [invalid]="showErrors"
  [errorMessage]="showErrors ? errorMessage : null"
>
  <mat-button-toggle-group [formControl]="control">
    <ng-container *ngFor="let option of input.options; let i = index">
      <mat-button-toggle [id]="inputId + '-' + i" [value]="option.value" [disabled]="option.disabled">{{ option.label }}</mat-button-toggle>
    </ng-container>
  </mat-button-toggle-group>
</mat-dynamic-form-input-wrapper>
`, dependencies: [{ kind: "directive", type: NgFor6, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "ngmodule", type: ReactiveFormsModule11 }, { kind: "directive", type: i213.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i213.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: MatDynamicFormInputWrapperComponent, selector: "mat-dynamic-form-input-wrapper", inputs: ["label", "inputId", "required", "disabled", "invalid", "errorMessage"] }, { kind: "ngmodule", type: MatButtonToggleModule }, { kind: "directive", type: i312.MatButtonToggleGroup, selector: "mat-button-toggle-group", inputs: ["appearance", "name", "vertical", "value", "multiple", "disabled", "hideSingleSelectionIndicator", "hideMultipleSelectionIndicator"], outputs: ["valueChange", "change"], exportAs: ["matButtonToggleGroup"] }, { kind: "component", type: i312.MatButtonToggle, selector: "mat-button-toggle", inputs: ["aria-label", "aria-labelledby", "id", "name", "value", "tabIndex", "disableRipple", "appearance", "checked", "disabled"], outputs: ["change"], exportAs: ["matButtonToggle"] }] });
  }
};
i024.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i024, type: MatDynamicFormToggleComponent, decorators: [{
  type: Component18,
  args: [{ standalone: true, selector: "mat-dynamic-form-toggle", imports: [NgFor6, ReactiveFormsModule11, MatDynamicFormInputWrapperComponent, MatButtonToggleModule], template: `<mat-dynamic-form-input-wrapper
  [inputId]="inputId"
  [label]="template.label"
  [required]="validation?.required"
  [disabled]="disabled"
  [invalid]="showErrors"
  [errorMessage]="showErrors ? errorMessage : null"
>
  <mat-button-toggle-group [formControl]="control">
    <ng-container *ngFor="let option of input.options; let i = index">
      <mat-button-toggle [id]="inputId + '-' + i" [value]="option.value" [disabled]="option.disabled">{{ option.label }}</mat-button-toggle>
    </ng-container>
  </mat-button-toggle-group>
</mat-dynamic-form-input-wrapper>
` }]
}], ctorParameters: () => [{ type: i116.DynamicFormValidationService }] });

// lib/dynamic-form-input/dynamic-form-toggle/dynamic-form-toggle-type.mjs
var matDynamicFormToggleType = {
  type: "toggle",
  component: MatDynamicFormToggleComponent,
  libraryName: matDynamicFormLibrary.name
};

// lib/dynamic-form-input/dynamic-form-input.module.mjs
import { NgModule as NgModule7 } from "@angular/core";
import { MAT_FORM_FIELD_DEFAULT_OPTIONS } from "@angular/material/form-field";
import { DynamicFormFileModule, DynamicFormTextboxModule, importDynamicFormsProviders as importDynamicFormsProviders5, withDynamicFormFileValidators, withDynamicFormInputs, withDynamicFormTextboxActionHandlers } from "@dynamic-forms/core";
import * as i025 from "@angular/core";
var matDynamicFormInputTypes = [
  matDynamicFormCheckboxType,
  matDynamicFormComboboxType,
  matDynamicFormDatepickerType,
  matDynamicFormFileType,
  matDynamicFormNumberboxType,
  matDynamicFormRadioType,
  matDynamicFormSelectType,
  matDynamicFormSwitchType,
  matDynamicFormTextareaType,
  matDynamicFormTextboxType,
  matDynamicFormToggleType
];
var matDynamicFormFieldDefaultOptions = { floatLabel: "always" };
function withMatDynamicFormFieldDefaultOptions(options = matDynamicFormFieldDefaultOptions) {
  return { providers: [{ provide: MAT_FORM_FIELD_DEFAULT_OPTIONS, useValue: options }] };
}
function withMatDynamicFormInputDefaultFeatures(options = matDynamicFormFieldDefaultOptions) {
  return [
    withDynamicFormInputs(...matDynamicFormInputTypes),
    withDynamicFormTextboxActionHandlers(),
    withDynamicFormFileValidators(),
    withMatDynamicFormFieldDefaultOptions(options)
  ];
}
var modules7 = [DynamicFormFileModule, DynamicFormTextboxModule];
var MatDynamicFormInputModule = class _MatDynamicFormInputModule {
  static {
    this.ɵfac = i025.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i025, type: _MatDynamicFormInputModule, deps: [], target: i025.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i025.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i025, type: _MatDynamicFormInputModule, imports: [DynamicFormFileModule, DynamicFormTextboxModule], exports: [DynamicFormFileModule, DynamicFormTextboxModule] });
  }
  static {
    this.ɵinj = i025.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i025, type: _MatDynamicFormInputModule, providers: importDynamicFormsProviders5(withDynamicFormInputs(...matDynamicFormInputTypes), withMatDynamicFormFieldDefaultOptions()), imports: [modules7, DynamicFormFileModule, DynamicFormTextboxModule] });
  }
};
i025.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i025, type: MatDynamicFormInputModule, decorators: [{
  type: NgModule7,
  args: [{
    imports: modules7,
    exports: modules7,
    providers: importDynamicFormsProviders5(withDynamicFormInputs(...matDynamicFormInputTypes), withMatDynamicFormFieldDefaultOptions())
  }]
}] });

// lib/dynamic-forms.module.mjs
import { NgModule as NgModule8 } from "@angular/core";
import { DynamicFormsModule, importDynamicFormsProviders as importDynamicFormsProviders6, provideDynamicForms, provideDynamicFormsWithDefaultFeatures, withDynamicFormValidation, withDynamicFormsIdBuilder, withDynamicFormsLibrary, withDynamicFormsTheme } from "@dynamic-forms/core";
import * as i026 from "@angular/core";
function provideMatDynamicForms(...features) {
  return [provideDynamicForms(matDynamicFormLibrary, ...features)];
}
var matDynamicFormsDefaultFeatures = [
  withDynamicFormValidation(),
  ...withMatDynamicFormActionDefaultFeatures(),
  ...withMatDynamicFormElementDefaultFeatures(),
  ...withMatDynamicFormInputDefaultFeatures()
];
function getDynamicFormsFeatures(config) {
  const features = [];
  if (config?.theme) {
    features.push(withDynamicFormsTheme(config?.theme));
  }
  if (config?.idBuilder) {
    features.push(withDynamicFormsIdBuilder(config?.idBuilder));
  }
  return features;
}
function provideMatDynamicFormsWithDefaultFeatures(config, ...additionalFeatures) {
  const features = [...matDynamicFormsDefaultFeatures, ...getDynamicFormsFeatures(config), ...additionalFeatures];
  return provideDynamicFormsWithDefaultFeatures(matDynamicFormLibrary, ...features);
}
var MatDynamicFormsModule = class _MatDynamicFormsModule {
  /**
   * @deprecated Use {@link provideMatDynamicFormsWithDefaultFeatures} instead.
   */
  static forRoot(config, ...additionalFeatures) {
    const features = [withDynamicFormsLibrary(matDynamicFormLibrary), ...getDynamicFormsFeatures(config), ...additionalFeatures];
    return { ngModule: _MatDynamicFormsModule, providers: importDynamicFormsProviders6(...features) };
  }
  static {
    this.ɵfac = i026.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i026, type: _MatDynamicFormsModule, deps: [], target: i026.ɵɵFactoryTarget.NgModule });
  }
  static {
    this.ɵmod = i026.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.0.0-next.6", ngImport: i026, type: _MatDynamicFormsModule, imports: [DynamicFormsModule], exports: [DynamicFormsModule] });
  }
  static {
    this.ɵinj = i026.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i026, type: _MatDynamicFormsModule, providers: provideDynamicFormsWithDefaultFeatures(null, ...matDynamicFormsDefaultFeatures, withDynamicFormValidation()), imports: [DynamicFormsModule, DynamicFormsModule] });
  }
};
i026.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.0.0-next.6", ngImport: i026, type: MatDynamicFormsModule, decorators: [{
  type: NgModule8,
  args: [{
    imports: [DynamicFormsModule],
    exports: [DynamicFormsModule],
    providers: provideDynamicFormsWithDefaultFeatures(null, ...matDynamicFormsDefaultFeatures, withDynamicFormValidation())
  }]
}] });
export {
  MatDynamicFormAccordionComponent,
  MatDynamicFormAccordionModule,
  MatDynamicFormActionModule,
  MatDynamicFormButtonComponent,
  MatDynamicFormCheckboxComponent,
  MatDynamicFormComboboxComponent,
  MatDynamicFormDatepickerComponent,
  MatDynamicFormDialogComponent,
  MatDynamicFormElementModule,
  MatDynamicFormFileComponent,
  MatDynamicFormIconComponent,
  MatDynamicFormInputModule,
  MatDynamicFormItemsModule,
  MatDynamicFormModalComponent,
  MatDynamicFormModalModule,
  MatDynamicFormNumberboxComponent,
  MatDynamicFormRadioComponent,
  MatDynamicFormSelectComponent,
  MatDynamicFormTabsComponent,
  MatDynamicFormTabsModule,
  MatDynamicFormTextareaComponent,
  MatDynamicFormTextboxComponent,
  MatDynamicFormsModule,
  matDynamicFormAccordionType,
  matDynamicFormActionTypes,
  matDynamicFormButtonType,
  matDynamicFormCheckboxType,
  matDynamicFormComboboxType,
  matDynamicFormDatepickerType,
  matDynamicFormElementTypes,
  matDynamicFormFieldDefaultOptions,
  matDynamicFormFileType,
  matDynamicFormIconType,
  matDynamicFormInputTypes,
  matDynamicFormLibrary,
  matDynamicFormModalType,
  matDynamicFormNumberboxType,
  matDynamicFormRadioType,
  matDynamicFormSelectType,
  matDynamicFormTabsType,
  matDynamicFormTextareaType,
  matDynamicFormTextboxType,
  matDynamicFormsDefaultFeatures,
  provideMatDynamicForms,
  provideMatDynamicFormsWithDefaultFeatures,
  withMatDynamicFormActionDefaultFeatures,
  withMatDynamicFormElementDefaultFeatures,
  withMatDynamicFormFieldDefaultOptions,
  withMatDynamicFormInputDefaultFeatures
};
//# sourceMappingURL=dynamic-forms-material.mjs.map
